function foo() {
    bar__2;
    function bar__2() {}
}
